@@ -1030,10 +1030,7 @@ func expandDuration(was []*withArgExpr, d *DurationExpr) (*DurationExpr, error)
 		return t, nil
 	case *NumberExpr:
 		// Convert number of seconds to DurationExpr
-		de := &DurationExpr{
-			s: t.s,
-		}
-		return de, nil
+		return newDurationExpr(t.s)
 	default:
 		return nil, fmt.Errorf("unexpected value for WITH template %q; got %s; want duration", d.s, e.AppendString(nil))
 	}
@@ -1631,26 +1628,33 @@ func (p *parser) parsePositiveDuration() (*DurationExpr, error) {
 		}
 	}
 	// Verify duration value.
-	if _, err := DurationValue(s, 0); err != nil {
-		return nil, fmt.Errorf(`duration: parse value error: %q: %w`, s, err)
-	}
 	if s == "$__interval" {
 		s = "1i"
 	}
+	return newDurationExpr(s)
+}
+
+// DurationExpr contains the duration
+type DurationExpr struct {
+	// s is a string representation of the duration.
+	//
+	// it must contain valid duration if needsParsing is set to false.
+	s string
+
+	// needsParsing is set to true if s isn't parsed yet with expandWithExpr()
+	needsParsing bool
+}
+
+func newDurationExpr(s string) (*DurationExpr, error) {
+	if _, err := DurationValue(s, 0); err != nil {
+		return nil, fmt.Errorf(`cannot parse duration %q: %w`, s, err)
+	}
 	de := &DurationExpr{
 		s: s,
 	}
 	return de, nil
 }
 
-// DurationExpr contains the duration
-type DurationExpr struct {
-	s string
-
-	// needsParsing is set to true if s isn't parsed yet with expandWithExpr()
-	needsParsing bool
-}
-
 // AppendString appends string representation of de to dst and returns the result.
 func (de *DurationExpr) AppendString(dst []byte) []byte {
 	if de == nil {
